@@ -13,11 +13,11 @@ import Data.Char (isSpace, toLower)
 import Data.Function (on)
 import Data.List as List (filter, groupBy, map, minimumBy, nub, sortBy)
 import Data.Map as Map (lookup, Map)
-import Data.Maybe (catMaybes, fromMaybe, isJust, isNothing)
+import Data.Maybe (catMaybes, fromMaybe, isJust, isNothing, listToMaybe)
 import Data.Set as Set (empty, fold, fromList, map, member, Set, singleton, toList, union)
 import Data.Version (showVersion, Version)
-import Debian.Debianize.BasicInfo (buildEnv, compilerFlavor, EnvSet(dependOS))
-import Debian.Debianize.Bundled (builtIn)
+import Debian.Debianize.BasicInfo (buildEnv, compilerFlavor, EnvSet(dependOS), verbosity)
+import Debian.Debianize.Bundled (builtIn, hcVersion)
 import qualified Debian.Debianize.DebInfo as D
 import Debian.Debianize.DebianName (mkPkgName, mkPkgName')
 import Debian.Debianize.Monad as Monad (CabalInfo, CabalT)
@@ -30,11 +30,13 @@ import Debian.Orphans ()
 import Debian.Relation (BinPkgName(..), checkVersionReq, Relation(..), Relations)
 import qualified Debian.Relation as D (BinPkgName(BinPkgName), Relation(..), Relations, VersionReq(EEQ, GRE, LTE, SGR, SLT))
 import Debian.Version (DebianVersion, parseDebianVersion')
+import Debug.Trace (trace)
 import Distribution.Compiler (CompilerFlavor(..))
-import Distribution.Package (Dependency(..), PackageName(PackageName))
+import Distribution.Package (Dependency(..), PackageIdentifier(pkgName, pkgVersion), PackageName(PackageName))
 import Distribution.PackageDescription (PackageDescription)
 import Distribution.PackageDescription as Cabal (BuildInfo(..), BuildInfo(buildTools, extraLibs, pkgconfigDepends), Library(..), Executable(..), TestSuite(..))
 import qualified Distribution.PackageDescription as Cabal (PackageDescription(library, executables, testSuites))
+import Distribution.Text (display)
 import Distribution.Version (anyVersion, asVersionIntervals, earlierVersion, foldVersionRange', fromVersionIntervals, intersectVersionRanges, isNoVersion, laterVersion, orEarlierVersion, orLaterVersion, toVersionIntervals, unionVersionRanges, VersionRange, withinVersion)
 import Distribution.Version.Invert (invertVersionRange)
 import Prelude hiding (init, log, map, unlines, unlines, writeFile)
@@ -330,12 +332,20 @@ doBundled typ name hc rels =
       doRel :: Monad m => D.Relation -> CabalT m [D.Relation]
       doRel rel@(D.Rel dname req _) = do
         -- gver <- use ghcVersion
-        splits <- use A.debianNameMap
         root <- use (A.debInfo . D.flags . buildEnv) >>= return . dependOS
         -- Look at what version of the package is provided by the compiler.
         atoms <- get
         -- What version of this package (if any) does the compiler provide?
-        let pver = maybe Nothing (Just . debianVersion'' atoms name) (builtIn splits hc root name)
+        let Just hcv = hcVersion root hc
+            relInfo = builtIn hc root
+            pver = listToMaybe $ fmap (debianVersion'' atoms) (filter ((== name) . pkgName) relInfo)
+            v = view (A.debInfo . D.flags . verbosity) atoms
+        case (v > 0, filter ((== name) . pkgName) relInfo) of
+          (True, [i]) ->
+              trace ("  " ++ show hc ++ "-" ++ show (showVersion hcv) ++ " in " ++ root ++ " provides " ++ display (pkgName i) ++ "-" ++ display (pkgVersion i)) (return ())
+          (True, _) ->
+              trace ("  " ++ show hc ++ "-" ++ show (showVersion hcv) ++ " in " ++ root ++ " does not provide " ++ display name) (return ())
+          _ -> return ()
         -- The name this library would have if it was in the compiler conflicts list.
         let naiveDebianName = mkPkgName hc name typ
         -- The compiler should appear in the build dependency
@@ -368,7 +378,7 @@ doBundled typ name hc rels =
       conflictsWithHC _ = True
 
 {-
-doBundled :: MonadIO m =>
+doBundled :: Monad m =>
              B.PackageType  -- Documentation, Profiling, Development...
           -> PackageName    -- Cabal package name
           -> [D.Relation]   -- Original set of debian dependencies
@@ -376,7 +386,7 @@ doBundled :: MonadIO m =>
 doBundled hc typ name rels =
     concat <$> mapM doRel rels
     where
-      doRel :: MonadIO m => D.Relation -> CabalT m [D.Relation]
+      doRel :: Monad m => D.Relation -> CabalT m [D.Relation]
       doRel rel@(D.Rel dname req _) = do
         hc <- use
 -}
@@ -387,8 +397,8 @@ debianVersion' name v =
     do atoms <- get
        return $ parseDebianVersion' (maybe "" (\ n -> show n ++ ":") (Map.lookup name (view A.epochMap atoms)) ++ showVersion v)
 
-debianVersion'' :: CabalInfo -> PackageName -> Version -> DebianVersion
-debianVersion'' atoms name v = parseDebianVersion' (maybe "" (\ n -> show n ++ ":") (Map.lookup name (view A.epochMap atoms)) ++ showVersion v)
+debianVersion'' :: CabalInfo -> PackageIdentifier -> DebianVersion
+debianVersion'' atoms i = parseDebianVersion' (maybe "" (\ n -> show n ++ ":") (Map.lookup (pkgName i) (view A.epochMap atoms)) ++ showVersion (pkgVersion i))
 
 data Rels a = And {unAnd :: [Rels a]} | Or {unOr :: [Rels a]} | Rel' {unRel :: a} deriving Show
 
